# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: demoparser/protobufs/base_gcmessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from demoparser.protobufs import steammessages_pb2 as demoparser_dot_protobufs_dot_steammessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='demoparser/protobufs/base_gcmessages.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n*demoparser/protobufs/base_gcmessages.proto\x1a(demoparser/protobufs/steammessages.proto\"}\n\x1d\x43GCStorePurchaseInit_LineItem\x12\x13\n\x0bitem_def_id\x18\x01 \x01(\r\x12\x10\n\x08quantity\x18\x02 \x01(\r\x12\x1e\n\x16\x63ost_in_local_currency\x18\x03 \x01(\r\x12\x15\n\rpurchase_type\x18\x04 \x01(\r\"\x82\x01\n\x17\x43MsgGCStorePurchaseInit\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\x05\x12\x10\n\x08\x63urrency\x18\x03 \x01(\x05\x12\x32\n\nline_items\x18\x04 \x03(\x0b\x32\x1e.CGCStorePurchaseInit_LineItem\"A\n\x1f\x43MsgGCStorePurchaseInitResponse\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\x0e\n\x06txn_id\x18\x02 \x01(\x04\"P\n\x0e\x43SOPartyInvite\x12\x16\n\x08group_id\x18\x01 \x01(\x04\x42\x04\x80\xa6\x1d\x01\x12\x11\n\tsender_id\x18\x02 \x01(\x06\x12\x13\n\x0bsender_name\x18\x03 \x01(\t\"P\n\x0e\x43SOLobbyInvite\x12\x16\n\x08group_id\x18\x01 \x01(\x04\x42\x04\x80\xa6\x1d\x01\x12\x11\n\tsender_id\x18\x02 \x01(\x06\x12\x13\n\x0bsender_name\x18\x03 \x01(\t\"&\n\x13\x43MsgSystemBroadcast\x12\x0f\n\x07message\x18\x01 \x01(\t\"R\n\x11\x43MsgInviteToParty\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x16\n\x0e\x63lient_version\x18\x02 \x01(\r\x12\x13\n\x0bteam_invite\x18\x03 \x01(\r\";\n\x15\x43MsgInvitationCreated\x12\x10\n\x08group_id\x18\x01 \x01(\x04\x12\x10\n\x08steam_id\x18\x02 \x01(\x06\"h\n\x17\x43MsgPartyInviteResponse\x12\x10\n\x08party_id\x18\x01 \x01(\x04\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lient_version\x18\x03 \x01(\r\x12\x13\n\x0bteam_invite\x18\x04 \x01(\r\"%\n\x11\x43MsgKickFromParty\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"\x10\n\x0e\x43MsgLeaveParty\"\x15\n\x13\x43MsgServerAvailable\"*\n\x16\x43MsgLANServerAvailable\x12\x10\n\x08lobby_id\x18\x01 \x01(\x06\"\xb4\x01\n\x18\x43SOEconGameAccountClient\x12$\n\x19\x61\x64\x64itional_backpack_slots\x18\x01 \x01(\r:\x01\x30\x12\"\n\x1a\x62onus_xp_timestamp_refresh\x18\x0c \x01(\x07\x12\x1a\n\x12\x62onus_xp_usedflags\x18\r \x01(\r\x12\x16\n\x0e\x65levated_state\x18\x0e \x01(\r\x12\x1a\n\x12\x65levated_timestamp\x18\x0f \x01(\r\"r\n\x18\x43SOItemCriteriaCondition\x12\n\n\x02op\x18\x01 \x01(\x05\x12\r\n\x05\x66ield\x18\x02 \x01(\t\x12\x10\n\x08required\x18\x03 \x01(\x08\x12\x13\n\x0b\x66loat_value\x18\x04 \x01(\x02\x12\x14\n\x0cstring_value\x18\x05 \x01(\t\"\xb1\x02\n\x0f\x43SOItemCriteria\x12\x12\n\nitem_level\x18\x01 \x01(\r\x12\x14\n\x0citem_quality\x18\x02 \x01(\x05\x12\x16\n\x0eitem_level_set\x18\x03 \x01(\x08\x12\x18\n\x10item_quality_set\x18\x04 \x01(\x08\x12\x19\n\x11initial_inventory\x18\x05 \x01(\r\x12\x18\n\x10initial_quantity\x18\x06 \x01(\r\x12\x1b\n\x13ignore_enabled_flag\x18\x08 \x01(\x08\x12-\n\nconditions\x18\t \x03(\x0b\x32\x19.CSOItemCriteriaCondition\x12\x13\n\x0bitem_rarity\x18\n \x01(\x05\x12\x17\n\x0fitem_rarity_set\x18\x0b \x01(\x08\x12\x13\n\x0brecent_only\x18\x0c \x01(\x08\"\xd5\x03\n\rCSOItemRecipe\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03n_a\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_inputs\x18\x04 \x01(\t\x12\x14\n\x0c\x64\x65sc_outputs\x18\x05 \x01(\t\x12\x0c\n\x04\x64i_a\x18\x06 \x01(\t\x12\x0c\n\x04\x64i_b\x18\x07 \x01(\t\x12\x0c\n\x04\x64i_c\x18\x08 \x01(\t\x12\x0c\n\x04\x64o_a\x18\t \x01(\t\x12\x0c\n\x04\x64o_b\x18\n \x01(\t\x12\x0c\n\x04\x64o_c\x18\x0b \x01(\t\x12\x1f\n\x17requires_all_same_class\x18\x0c \x01(\x08\x12\x1e\n\x16requires_all_same_slot\x18\r \x01(\x08\x12\x1e\n\x16\x63lass_usage_for_output\x18\x0e \x01(\x05\x12\x1d\n\x15slot_usage_for_output\x18\x0f \x01(\x05\x12\x16\n\x0eset_for_output\x18\x10 \x01(\x05\x12.\n\x14input_items_criteria\x18\x14 \x03(\x0b\x32\x10.CSOItemCriteria\x12/\n\x15output_items_criteria\x18\x15 \x03(\x0b\x32\x10.CSOItemCriteria\x12\x1e\n\x16input_item_dupe_counts\x18\x16 \x03(\r\"M\n\x15\x43MsgDevNewItemRequest\x12\x10\n\x08receiver\x18\x01 \x01(\x06\x12\"\n\x08\x63riteria\x18\x02 \x01(\x0b\x32\x10.CSOItemCriteria\"\x8c\x01\n\x1f\x43MsgIncrementKillCountAttribute\x12\x19\n\x11killer_account_id\x18\x01 \x01(\x07\x12\x19\n\x11victim_account_id\x18\x02 \x01(\x07\x12\x0f\n\x07item_id\x18\x03 \x01(\x04\x12\x12\n\nevent_type\x18\x04 \x01(\r\x12\x0e\n\x06\x61mount\x18\x05 \x01(\r\"\x86\x01\n\x10\x43MsgApplySticker\x12\x17\n\x0fsticker_item_id\x18\x01 \x01(\x04\x12\x14\n\x0citem_item_id\x18\x02 \x01(\x04\x12\x14\n\x0csticker_slot\x18\x03 \x01(\r\x12\x17\n\x0f\x62\x61seitem_defidx\x18\x04 \x01(\r\x12\x14\n\x0csticker_wear\x18\x05 \x01(\x02\"]\n\x15\x43MsgApplyStatTrakSwap\x12\x14\n\x0ctool_item_id\x18\x01 \x01(\x04\x12\x16\n\x0eitem_1_item_id\x18\x02 \x01(\x04\x12\x16\n\x0eitem_2_item_id\x18\x03 \x01(\x04\"J\n\x14\x43MsgApplyStrangePart\x12\x1c\n\x14strange_part_item_id\x18\x01 \x01(\x04\x12\x14\n\x0citem_item_id\x18\x02 \x01(\x04\"K\n\x17\x43MsgApplyPennantUpgrade\x12\x17\n\x0fupgrade_item_id\x18\x01 \x01(\x04\x12\x17\n\x0fpennant_item_id\x18\x02 \x01(\x04\"C\n\x13\x43MsgApplyEggEssence\x12\x17\n\x0f\x65ssence_item_id\x18\x01 \x01(\x04\x12\x13\n\x0b\x65gg_item_id\x18\x02 \x01(\x04\"M\n\x14\x43SOEconItemAttribute\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r\x12\x13\n\x0bvalue_bytes\x18\x03 \x01(\x0c\":\n\x13\x43SOEconItemEquipped\x12\x11\n\tnew_class\x18\x01 \x01(\r\x12\x10\n\x08new_slot\x18\x02 \x01(\r\"\x9f\x03\n\x0b\x43SOEconItem\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x12\n\naccount_id\x18\x02 \x01(\r\x12\x11\n\tinventory\x18\x03 \x01(\r\x12\x11\n\tdef_index\x18\x04 \x01(\r\x12\x10\n\x08quantity\x18\x05 \x01(\r\x12\r\n\x05level\x18\x06 \x01(\r\x12\x0f\n\x07quality\x18\x07 \x01(\r\x12\x10\n\x05\x66lags\x18\x08 \x01(\r:\x01\x30\x12\x0e\n\x06origin\x18\t \x01(\r\x12\x13\n\x0b\x63ustom_name\x18\n \x01(\t\x12\x13\n\x0b\x63ustom_desc\x18\x0b \x01(\t\x12(\n\tattribute\x18\x0c \x03(\x0b\x32\x15.CSOEconItemAttribute\x12#\n\rinterior_item\x18\r \x01(\x0b\x32\x0c.CSOEconItem\x12\x15\n\x06in_use\x18\x0e \x01(\x08:\x05\x66\x61lse\x12\x10\n\x05style\x18\x0f \x01(\r:\x01\x30\x12\x16\n\x0boriginal_id\x18\x10 \x01(\x04:\x01\x30\x12,\n\x0e\x65quipped_state\x18\x12 \x03(\x0b\x32\x14.CSOEconItemEquipped\x12\x0e\n\x06rarity\x18\x13 \x01(\r\"a\n\x1b\x43MsgAdjustItemEquippedState\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x11\n\tnew_class\x18\x02 \x01(\r\x12\x10\n\x08new_slot\x18\x03 \x01(\r\x12\x0c\n\x04swap\x18\x04 \x01(\x08\"\"\n\rCMsgSortItems\x12\x11\n\tsort_type\x18\x01 \x01(\r\"^\n\x10\x43SOEconClaimCode\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\tcode_type\x18\x02 \x01(\r\x12\x15\n\rtime_acquired\x18\x03 \x01(\r\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\"E\n\x14\x43MsgStoreGetUserData\x12\x1b\n\x13price_sheet_version\x18\x01 \x01(\x07\x12\x10\n\x08\x63urrency\x18\x02 \x01(\x05\"\x99\x01\n\x1c\x43MsgStoreGetUserDataResponse\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\x1b\n\x13\x63urrency_deprecated\x18\x02 \x01(\x05\x12\x1a\n\x12\x63ountry_deprecated\x18\x03 \x01(\t\x12\x1b\n\x13price_sheet_version\x18\x04 \x01(\x07\x12\x13\n\x0bprice_sheet\x18\x08 \x01(\x0c\"\x86\x01\n\x14\x43MsgUpdateItemSchema\x12\x12\n\nitems_game\x18\x01 \x01(\x0c\x12\x1b\n\x13item_schema_version\x18\x02 \x01(\x07\x12%\n\x1ditems_game_url_DEPRECATED2013\x18\x03 \x01(\t\x12\x16\n\x0eitems_game_url\x18\x04 \x01(\t\"!\n\x0b\x43MsgGCError\x12\x12\n\nerror_text\x18\x01 \x01(\t\"\x1d\n\x1b\x43MsgRequestInventoryRefresh\".\n\x0f\x43MsgConVarValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"9\n\x14\x43MsgReplicateConVars\x12!\n\x07\x63onvars\x18\x01 \x03(\x0b\x32\x10.CMsgConVarValue\"\x8e\x01\n\x0b\x43MsgUseItem\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x17\n\x0ftarget_steam_id\x18\x02 \x01(\x06\x12\x1f\n\x17gift__potential_targets\x18\x03 \x03(\r\x12\x18\n\x10\x64uel__class_lock\x18\x04 \x01(\r\x12\x1a\n\x12initiator_steam_id\x18\x05 \x01(\x06\"d\n\x1b\x43MsgReplayUploadedToYouTube\x12\x13\n\x0byoutube_url\x18\x01 \x01(\t\x12\x1c\n\x14youtube_account_name\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\x04\".\n\x17\x43MsgConsumableExhausted\x12\x13\n\x0bitem_def_id\x18\x01 \x01(\x05\"\x9e\x01\n CMsgItemAcknowledged__DEPRECATED\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\tinventory\x18\x02 \x01(\r\x12\x11\n\tdef_index\x18\x03 \x01(\r\x12\x0f\n\x07quality\x18\x04 \x01(\r\x12\x0e\n\x06rarity\x18\x05 \x01(\r\x12\x0e\n\x06origin\x18\x06 \x01(\r\x12\x0f\n\x07item_id\x18\x07 \x01(\x04\"\x9d\x01\n\x14\x43MsgSetItemPositions\x12:\n\x0eitem_positions\x18\x01 \x03(\x0b\x32\".CMsgSetItemPositions.ItemPosition\x1aI\n\x0cItemPosition\x12\x16\n\x0elegacy_item_id\x18\x01 \x01(\r\x12\x10\n\x08position\x18\x02 \x01(\r\x12\x0f\n\x07item_id\x18\x03 \x01(\x04\"\xb8\x01\n\x11\x43MsgGCReportAbuse\x12\x17\n\x0ftarget_steam_id\x18\x01 \x01(\x06\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0b\n\x03gid\x18\x05 \x01(\x04\x12\x12\n\nabuse_type\x18\x02 \x01(\r\x12\x14\n\x0c\x63ontent_type\x18\x03 \x01(\r\x12\x1d\n\x15target_game_server_ip\x18\x06 \x01(\x07\x12\x1f\n\x17target_game_server_port\x18\x07 \x01(\r\"[\n\x19\x43MsgGCReportAbuseResponse\x12\x17\n\x0ftarget_steam_id\x18\x01 \x01(\x06\x12\x0e\n\x06result\x18\x02 \x01(\r\x12\x15\n\rerror_message\x18\x03 \x01(\t\"f\n\x1a\x43MsgGCNameItemNotification\x12\x16\n\x0eplayer_steamid\x18\x01 \x01(\x06\x12\x16\n\x0eitem_def_index\x18\x02 \x01(\r\x12\x18\n\x10item_name_custom\x18\x03 \x01(\t\"\xb6\x01\n\x1f\x43MsgGCClientDisplayNotification\x12+\n#notification_title_localization_key\x18\x01 \x01(\t\x12*\n\"notification_body_localization_key\x18\x02 \x01(\t\x12\x1b\n\x13\x62ody_substring_keys\x18\x03 \x03(\t\x12\x1d\n\x15\x62ody_substring_values\x18\x04 \x03(\t\"1\n\x17\x43MsgGCShowItemsPickedUp\x12\x16\n\x0eplayer_steamid\x18\x01 \x01(\x06\"|\n CMsgGCIncrementKillCountResponse\x12\x1f\n\x11killer_account_id\x18\x01 \x01(\rB\x04\x80\xa6\x1d\x01\x12\x11\n\tnum_kills\x18\x02 \x01(\r\x12\x10\n\x08item_def\x18\x03 \x01(\r\x12\x12\n\nlevel_type\x18\x04 \x01(\r\"\x8f\x01\n\x18\x43SOEconItemDropRateBonus\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x17\n\x0f\x65xpiration_date\x18\x02 \x01(\x07\x12\r\n\x05\x62onus\x18\x03 \x01(\x02\x12\x13\n\x0b\x62onus_count\x18\x04 \x01(\r\x12\x0f\n\x07item_id\x18\x05 \x01(\x04\x12\x11\n\tdef_index\x18\x06 \x01(\r\"p\n\x19\x43SOEconItemLeagueViewPass\x12\x18\n\naccount_id\x18\x01 \x01(\rB\x04\x80\xa6\x1d\x01\x12\x17\n\tleague_id\x18\x02 \x01(\rB\x04\x80\xa6\x1d\x01\x12\r\n\x05\x61\x64min\x18\x03 \x01(\r\x12\x11\n\titemindex\x18\x04 \x01(\r\"O\n\x16\x43SOEconItemEventTicket\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\r\x12\x0f\n\x07item_id\x18\x03 \x01(\x04\"A\n\'CMsgGCItemPreviewItemBoughtNotification\x12\x16\n\x0eitem_def_index\x18\x01 \x01(\r\"+\n\x19\x43MsgGCStorePurchaseCancel\x12\x0e\n\x06txn_id\x18\x01 \x01(\x04\"3\n!CMsgGCStorePurchaseCancelResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"-\n\x1b\x43MsgGCStorePurchaseFinalize\x12\x0e\n\x06txn_id\x18\x01 \x01(\x04\"G\n#CMsgGCStorePurchaseFinalizeResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x10\n\x08item_ids\x18\x02 \x03(\x04\"I\n\x1b\x43MsgGCBannedWordListRequest\x12\x19\n\x11\x62\x61n_list_group_id\x18\x01 \x01(\r\x12\x0f\n\x07word_id\x18\x02 \x01(\r\"\x1c\n\x1a\x43MsgGCRequestAnnouncements\"\x82\x01\n\"CMsgGCRequestAnnouncementsResponse\x12\x1a\n\x12\x61nnouncement_title\x18\x01 \x01(\t\x12\x14\n\x0c\x61nnouncement\x18\x02 \x01(\t\x12\x17\n\x0fnextmatch_title\x18\x03 \x01(\t\x12\x11\n\tnextmatch\x18\x04 \x01(\t\"u\n\x10\x43MsgGCBannedWord\x12\x0f\n\x07word_id\x18\x01 \x01(\r\x12\x42\n\tword_type\x18\x02 \x01(\x0e\x32\x12.GC_BannedWordType:\x1bGC_BANNED_WORD_DISABLE_WORD\x12\x0c\n\x04word\x18\x03 \x01(\t\"_\n\x1c\x43MsgGCBannedWordListResponse\x12\x19\n\x11\x62\x61n_list_group_id\x18\x01 \x01(\r\x12$\n\tword_list\x18\x02 \x03(\x0b\x32\x11.CMsgGCBannedWord\"U\n!CMsgGCToGCBannedWordListBroadcast\x12\x30\n\tbroadcast\x18\x01 \x01(\x0b\x32\x1d.CMsgGCBannedWordListResponse\"3\n\x1f\x43MsgGCToGCBannedWordListUpdated\x12\x10\n\x08group_id\x18\x01 \x01(\r\"\x92\x01\n.CSOEconDefaultEquippedDefinitionInstanceClient\x12\x18\n\naccount_id\x18\x01 \x01(\rB\x04\x80\xa6\x1d\x01\x12\x17\n\x0fitem_definition\x18\x02 \x01(\r\x12\x16\n\x08\x63lass_id\x18\x03 \x01(\rB\x04\x80\xa6\x1d\x01\x12\x15\n\x07slot_id\x18\x04 \x01(\rB\x04\x80\xa6\x1d\x01\"?\n\x17\x43MsgGCToGCDirtySDOCache\x12\x10\n\x08sdo_type\x18\x01 \x01(\r\x12\x12\n\nkey_uint64\x18\x02 \x01(\x04\"G\n\x1f\x43MsgGCToGCDirtyMultipleSDOCache\x12\x10\n\x08sdo_type\x18\x01 \x01(\r\x12\x12\n\nkey_uint64\x18\x02 \x03(\x04\"H\n\x11\x43MsgGCCollectItem\x12\x1a\n\x12\x63ollection_item_id\x18\x01 \x01(\x04\x12\x17\n\x0fsubject_item_id\x18\x02 \x01(\x04\"\x14\n\x12\x43MsgSDONoMemcached\"/\n\x1b\x43MsgGCToGCUpdateSQLKeyValue\x12\x10\n\x08key_name\x18\x01 \x01(\t\"-\n\x19\x43MsgGCToGCIsTrustedServer\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"7\n!CMsgGCToGCIsTrustedServerResponse\x12\x12\n\nis_trusted\x18\x01 \x01(\x08\"8\n!CMsgGCToGCBroadcastConsoleCommand\x12\x13\n\x0b\x63on_command\x18\x01 \x01(\t\"4\n\x1a\x43MsgGCServerVersionUpdated\x12\x16\n\x0eserver_version\x18\x01 \x01(\r\"4\n\x1a\x43MsgGCClientVersionUpdated\x12\x16\n\x0e\x63lient_version\x18\x01 \x01(\r\" \n\x1e\x43MsgGCToGCWebAPIAccountChanged\"^\n\"CMsgGCToGCRequestPassportItemGrant\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x11\n\tleague_id\x18\x02 \x01(\r\x12\x13\n\x0breward_flag\x18\x03 \x01(\x05\"\xe8\x04\n\x12\x43MsgGameServerInfo\x12\x1d\n\x15server_public_ip_addr\x18\x01 \x01(\x07\x12\x1e\n\x16server_private_ip_addr\x18\x02 \x01(\x07\x12\x13\n\x0bserver_port\x18\x03 \x01(\r\x12\x16\n\x0eserver_tv_port\x18\x04 \x01(\r\x12\x12\n\nserver_key\x18\x05 \x01(\t\x12\x1a\n\x12server_hibernation\x18\x06 \x01(\x08\x12@\n\x0bserver_type\x18\x07 \x01(\x0e\x32\x1e.CMsgGameServerInfo.ServerType:\x0bUNSPECIFIED\x12\x15\n\rserver_region\x18\x08 \x01(\r\x12\x16\n\x0eserver_loadavg\x18\t \x01(\x02\x12 \n\x18server_tv_broadcast_time\x18\n \x01(\x02\x12\x18\n\x10server_game_time\x18\x0b \x01(\x02\x12\'\n\x1fserver_relay_connected_steam_id\x18\x0c \x01(\x06\x12\x17\n\x0frelay_slots_max\x18\r \x01(\r\x12\x18\n\x10relays_connected\x18\x0e \x01(\x05\x12\x1f\n\x17relay_clients_connected\x18\x0f \x01(\x05\x12$\n\x1crelayed_game_server_steam_id\x18\x10 \x01(\x06\x12\x1a\n\x12parent_relay_count\x18\x11 \x01(\r\x12\x16\n\x0etv_secret_code\x18\x12 \x01(\x06\"2\n\nServerType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04GAME\x10\x01\x12\t\n\x05PROXY\x10\x02*\xc7\x03\n\nEGCBaseMsg\x12\x1a\n\x15k_EMsgGCSystemMessage\x10\xa1\x1f\x12\x1d\n\x18k_EMsgGCReplicateConVars\x10\xa2\x1f\x12\x1a\n\x15k_EMsgGCConVarUpdated\x10\xa3\x1f\x12\x14\n\x0fk_EMsgGCInQueue\x10\xa8\x1f\x12\x1a\n\x15k_EMsgGCInviteToParty\x10\x95#\x12\x1e\n\x19k_EMsgGCInvitationCreated\x10\x96#\x12 \n\x1bk_EMsgGCPartyInviteResponse\x10\x97#\x12\x1a\n\x15k_EMsgGCKickFromParty\x10\x98#\x12\x17\n\x12k_EMsgGCLeaveParty\x10\x99#\x12\x1c\n\x17k_EMsgGCServerAvailable\x10\x9a#\x12\"\n\x1dk_EMsgGCClientConnectToServer\x10\x9b#\x12\x1b\n\x16k_EMsgGCGameServerInfo\x10\x9c#\x12\x12\n\rk_EMsgGCError\x10\x9d#\x12%\n k_EMsgGCReplay_UploadedToYouTube\x10\x9e#\x12\x1f\n\x1ak_EMsgGCLANServerAvailable\x10\x9f#*Y\n\x17\x45GCBaseProtoObjectTypes\x12\x1e\n\x19k_EProtoObjectPartyInvite\x10\xe9\x07\x12\x1e\n\x19k_EProtoObjectLobbyInvite\x10\xea\x07*T\n\x11GC_BannedWordType\x12\x1f\n\x1bGC_BANNED_WORD_DISABLE_WORD\x10\x00\x12\x1e\n\x1aGC_BANNED_WORD_ENABLE_WORD\x10\x01\x42\x05H\x01\x80\x01\x00')
  ,
  dependencies=[demoparser_dot_protobufs_dot_steammessages__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_EGCBASEMSG = _descriptor.EnumDescriptor(
  name='EGCBaseMsg',
  full_name='EGCBaseMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSystemMessage', index=0, number=4001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCReplicateConVars', index=1, number=4002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCConVarUpdated', index=2, number=4003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCInQueue', index=3, number=4008,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCInviteToParty', index=4, number=4501,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCInvitationCreated', index=5, number=4502,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPartyInviteResponse', index=6, number=4503,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCKickFromParty', index=7, number=4504,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeaveParty', index=8, number=4505,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerAvailable', index=9, number=4506,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientConnectToServer', index=10, number=4507,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGameServerInfo', index=11, number=4508,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCError', index=12, number=4509,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCReplay_UploadedToYouTube', index=13, number=4510,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLANServerAvailable', index=14, number=4511,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8108,
  serialized_end=8563,
)
_sym_db.RegisterEnumDescriptor(_EGCBASEMSG)

EGCBaseMsg = enum_type_wrapper.EnumTypeWrapper(_EGCBASEMSG)
_EGCBASEPROTOOBJECTTYPES = _descriptor.EnumDescriptor(
  name='EGCBaseProtoObjectTypes',
  full_name='EGCBaseProtoObjectTypes',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EProtoObjectPartyInvite', index=0, number=1001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProtoObjectLobbyInvite', index=1, number=1002,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8565,
  serialized_end=8654,
)
_sym_db.RegisterEnumDescriptor(_EGCBASEPROTOOBJECTTYPES)

EGCBaseProtoObjectTypes = enum_type_wrapper.EnumTypeWrapper(_EGCBASEPROTOOBJECTTYPES)
_GC_BANNEDWORDTYPE = _descriptor.EnumDescriptor(
  name='GC_BannedWordType',
  full_name='GC_BannedWordType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GC_BANNED_WORD_DISABLE_WORD', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GC_BANNED_WORD_ENABLE_WORD', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8656,
  serialized_end=8740,
)
_sym_db.RegisterEnumDescriptor(_GC_BANNEDWORDTYPE)

GC_BannedWordType = enum_type_wrapper.EnumTypeWrapper(_GC_BANNEDWORDTYPE)
k_EMsgGCSystemMessage = 4001
k_EMsgGCReplicateConVars = 4002
k_EMsgGCConVarUpdated = 4003
k_EMsgGCInQueue = 4008
k_EMsgGCInviteToParty = 4501
k_EMsgGCInvitationCreated = 4502
k_EMsgGCPartyInviteResponse = 4503
k_EMsgGCKickFromParty = 4504
k_EMsgGCLeaveParty = 4505
k_EMsgGCServerAvailable = 4506
k_EMsgGCClientConnectToServer = 4507
k_EMsgGCGameServerInfo = 4508
k_EMsgGCError = 4509
k_EMsgGCReplay_UploadedToYouTube = 4510
k_EMsgGCLANServerAvailable = 4511
k_EProtoObjectPartyInvite = 1001
k_EProtoObjectLobbyInvite = 1002
GC_BANNED_WORD_DISABLE_WORD = 0
GC_BANNED_WORD_ENABLE_WORD = 1


_CMSGGAMESERVERINFO_SERVERTYPE = _descriptor.EnumDescriptor(
  name='ServerType',
  full_name='CMsgGameServerInfo.ServerType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GAME', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROXY', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8055,
  serialized_end=8105,
)
_sym_db.RegisterEnumDescriptor(_CMSGGAMESERVERINFO_SERVERTYPE)


_CGCSTOREPURCHASEINIT_LINEITEM = _descriptor.Descriptor(
  name='CGCStorePurchaseInit_LineItem',
  full_name='CGCStorePurchaseInit_LineItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def_id', full_name='CGCStorePurchaseInit_LineItem.item_def_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CGCStorePurchaseInit_LineItem.quantity', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cost_in_local_currency', full_name='CGCStorePurchaseInit_LineItem.cost_in_local_currency', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='purchase_type', full_name='CGCStorePurchaseInit_LineItem.purchase_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=213,
)


_CMSGGCSTOREPURCHASEINIT = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseInit',
  full_name='CMsgGCStorePurchaseInit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='country', full_name='CMsgGCStorePurchaseInit.country', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='CMsgGCStorePurchaseInit.language', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='CMsgGCStorePurchaseInit.currency', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='line_items', full_name='CMsgGCStorePurchaseInit.line_items', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=216,
  serialized_end=346,
)


_CMSGGCSTOREPURCHASEINITRESPONSE = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseInitResponse',
  full_name='CMsgGCStorePurchaseInitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCStorePurchaseInitResponse.result', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='txn_id', full_name='CMsgGCStorePurchaseInitResponse.txn_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=413,
)


_CSOPARTYINVITE = _descriptor.Descriptor(
  name='CSOPartyInvite',
  full_name='CSOPartyInvite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='CSOPartyInvite.group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='CSOPartyInvite.sender_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sender_name', full_name='CSOPartyInvite.sender_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=495,
)


_CSOLOBBYINVITE = _descriptor.Descriptor(
  name='CSOLobbyInvite',
  full_name='CSOLobbyInvite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='CSOLobbyInvite.group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='CSOLobbyInvite.sender_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sender_name', full_name='CSOLobbyInvite.sender_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=577,
)


_CMSGSYSTEMBROADCAST = _descriptor.Descriptor(
  name='CMsgSystemBroadcast',
  full_name='CMsgSystemBroadcast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgSystemBroadcast.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=579,
  serialized_end=617,
)


_CMSGINVITETOPARTY = _descriptor.Descriptor(
  name='CMsgInviteToParty',
  full_name='CMsgInviteToParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgInviteToParty.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgInviteToParty.client_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_invite', full_name='CMsgInviteToParty.team_invite', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=619,
  serialized_end=701,
)


_CMSGINVITATIONCREATED = _descriptor.Descriptor(
  name='CMsgInvitationCreated',
  full_name='CMsgInvitationCreated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='CMsgInvitationCreated.group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgInvitationCreated.steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=703,
  serialized_end=762,
)


_CMSGPARTYINVITERESPONSE = _descriptor.Descriptor(
  name='CMsgPartyInviteResponse',
  full_name='CMsgPartyInviteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='party_id', full_name='CMsgPartyInviteResponse.party_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='accept', full_name='CMsgPartyInviteResponse.accept', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgPartyInviteResponse.client_version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_invite', full_name='CMsgPartyInviteResponse.team_invite', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=764,
  serialized_end=868,
)


_CMSGKICKFROMPARTY = _descriptor.Descriptor(
  name='CMsgKickFromParty',
  full_name='CMsgKickFromParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgKickFromParty.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=870,
  serialized_end=907,
)


_CMSGLEAVEPARTY = _descriptor.Descriptor(
  name='CMsgLeaveParty',
  full_name='CMsgLeaveParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=909,
  serialized_end=925,
)


_CMSGSERVERAVAILABLE = _descriptor.Descriptor(
  name='CMsgServerAvailable',
  full_name='CMsgServerAvailable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=948,
)


_CMSGLANSERVERAVAILABLE = _descriptor.Descriptor(
  name='CMsgLANServerAvailable',
  full_name='CMsgLANServerAvailable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgLANServerAvailable.lobby_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=950,
  serialized_end=992,
)


_CSOECONGAMEACCOUNTCLIENT = _descriptor.Descriptor(
  name='CSOEconGameAccountClient',
  full_name='CSOEconGameAccountClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='additional_backpack_slots', full_name='CSOEconGameAccountClient.additional_backpack_slots', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bonus_xp_timestamp_refresh', full_name='CSOEconGameAccountClient.bonus_xp_timestamp_refresh', index=1,
      number=12, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bonus_xp_usedflags', full_name='CSOEconGameAccountClient.bonus_xp_usedflags', index=2,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='elevated_state', full_name='CSOEconGameAccountClient.elevated_state', index=3,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='elevated_timestamp', full_name='CSOEconGameAccountClient.elevated_timestamp', index=4,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=995,
  serialized_end=1175,
)


_CSOITEMCRITERIACONDITION = _descriptor.Descriptor(
  name='CSOItemCriteriaCondition',
  full_name='CSOItemCriteriaCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='op', full_name='CSOItemCriteriaCondition.op', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='field', full_name='CSOItemCriteriaCondition.field', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='required', full_name='CSOItemCriteriaCondition.required', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='CSOItemCriteriaCondition.float_value', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='CSOItemCriteriaCondition.string_value', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1177,
  serialized_end=1291,
)


_CSOITEMCRITERIA = _descriptor.Descriptor(
  name='CSOItemCriteria',
  full_name='CSOItemCriteria',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_level', full_name='CSOItemCriteria.item_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_quality', full_name='CSOItemCriteria.item_quality', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_level_set', full_name='CSOItemCriteria.item_level_set', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_quality_set', full_name='CSOItemCriteria.item_quality_set', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initial_inventory', full_name='CSOItemCriteria.initial_inventory', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initial_quantity', full_name='CSOItemCriteria.initial_quantity', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ignore_enabled_flag', full_name='CSOItemCriteria.ignore_enabled_flag', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='CSOItemCriteria.conditions', index=7,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_rarity', full_name='CSOItemCriteria.item_rarity', index=8,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_rarity_set', full_name='CSOItemCriteria.item_rarity_set', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recent_only', full_name='CSOItemCriteria.recent_only', index=10,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1294,
  serialized_end=1599,
)


_CSOITEMRECIPE = _descriptor.Descriptor(
  name='CSOItemRecipe',
  full_name='CSOItemRecipe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CSOItemRecipe.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSOItemRecipe.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='n_a', full_name='CSOItemRecipe.n_a', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desc_inputs', full_name='CSOItemRecipe.desc_inputs', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desc_outputs', full_name='CSOItemRecipe.desc_outputs', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='di_a', full_name='CSOItemRecipe.di_a', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='di_b', full_name='CSOItemRecipe.di_b', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='di_c', full_name='CSOItemRecipe.di_c', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='do_a', full_name='CSOItemRecipe.do_a', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='do_b', full_name='CSOItemRecipe.do_b', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='do_c', full_name='CSOItemRecipe.do_c', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='requires_all_same_class', full_name='CSOItemRecipe.requires_all_same_class', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='requires_all_same_slot', full_name='CSOItemRecipe.requires_all_same_slot', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='class_usage_for_output', full_name='CSOItemRecipe.class_usage_for_output', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_usage_for_output', full_name='CSOItemRecipe.slot_usage_for_output', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='set_for_output', full_name='CSOItemRecipe.set_for_output', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='input_items_criteria', full_name='CSOItemRecipe.input_items_criteria', index=16,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='output_items_criteria', full_name='CSOItemRecipe.output_items_criteria', index=17,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='input_item_dupe_counts', full_name='CSOItemRecipe.input_item_dupe_counts', index=18,
      number=22, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1602,
  serialized_end=2071,
)


_CMSGDEVNEWITEMREQUEST = _descriptor.Descriptor(
  name='CMsgDevNewItemRequest',
  full_name='CMsgDevNewItemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='receiver', full_name='CMsgDevNewItemRequest.receiver', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='criteria', full_name='CMsgDevNewItemRequest.criteria', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2073,
  serialized_end=2150,
)


_CMSGINCREMENTKILLCOUNTATTRIBUTE = _descriptor.Descriptor(
  name='CMsgIncrementKillCountAttribute',
  full_name='CMsgIncrementKillCountAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='killer_account_id', full_name='CMsgIncrementKillCountAttribute.killer_account_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='victim_account_id', full_name='CMsgIncrementKillCountAttribute.victim_account_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgIncrementKillCountAttribute.item_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='CMsgIncrementKillCountAttribute.event_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='CMsgIncrementKillCountAttribute.amount', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2153,
  serialized_end=2293,
)


_CMSGAPPLYSTICKER = _descriptor.Descriptor(
  name='CMsgApplySticker',
  full_name='CMsgApplySticker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sticker_item_id', full_name='CMsgApplySticker.sticker_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='CMsgApplySticker.item_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sticker_slot', full_name='CMsgApplySticker.sticker_slot', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='baseitem_defidx', full_name='CMsgApplySticker.baseitem_defidx', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sticker_wear', full_name='CMsgApplySticker.sticker_wear', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2296,
  serialized_end=2430,
)


_CMSGAPPLYSTATTRAKSWAP = _descriptor.Descriptor(
  name='CMsgApplyStatTrakSwap',
  full_name='CMsgApplyStatTrakSwap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tool_item_id', full_name='CMsgApplyStatTrakSwap.tool_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_1_item_id', full_name='CMsgApplyStatTrakSwap.item_1_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_2_item_id', full_name='CMsgApplyStatTrakSwap.item_2_item_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2432,
  serialized_end=2525,
)


_CMSGAPPLYSTRANGEPART = _descriptor.Descriptor(
  name='CMsgApplyStrangePart',
  full_name='CMsgApplyStrangePart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strange_part_item_id', full_name='CMsgApplyStrangePart.strange_part_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='CMsgApplyStrangePart.item_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2527,
  serialized_end=2601,
)


_CMSGAPPLYPENNANTUPGRADE = _descriptor.Descriptor(
  name='CMsgApplyPennantUpgrade',
  full_name='CMsgApplyPennantUpgrade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='upgrade_item_id', full_name='CMsgApplyPennantUpgrade.upgrade_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pennant_item_id', full_name='CMsgApplyPennantUpgrade.pennant_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2603,
  serialized_end=2678,
)


_CMSGAPPLYEGGESSENCE = _descriptor.Descriptor(
  name='CMsgApplyEggEssence',
  full_name='CMsgApplyEggEssence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='essence_item_id', full_name='CMsgApplyEggEssence.essence_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='egg_item_id', full_name='CMsgApplyEggEssence.egg_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2680,
  serialized_end=2747,
)


_CSOECONITEMATTRIBUTE = _descriptor.Descriptor(
  name='CSOEconItemAttribute',
  full_name='CSOEconItemAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CSOEconItemAttribute.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='CSOEconItemAttribute.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value_bytes', full_name='CSOEconItemAttribute.value_bytes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2749,
  serialized_end=2826,
)


_CSOECONITEMEQUIPPED = _descriptor.Descriptor(
  name='CSOEconItemEquipped',
  full_name='CSOEconItemEquipped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_class', full_name='CSOEconItemEquipped.new_class', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_slot', full_name='CSOEconItemEquipped.new_slot', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2828,
  serialized_end=2886,
)


_CSOECONITEM = _descriptor.Descriptor(
  name='CSOEconItem',
  full_name='CSOEconItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CSOEconItem.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSOEconItem.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inventory', full_name='CSOEconItem.inventory', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CSOEconItem.def_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CSOEconItem.quantity', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='CSOEconItem.level', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality', full_name='CSOEconItem.quality', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CSOEconItem.flags', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin', full_name='CSOEconItem.origin', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_name', full_name='CSOEconItem.custom_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_desc', full_name='CSOEconItem.custom_desc', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='CSOEconItem.attribute', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interior_item', full_name='CSOEconItem.interior_item', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_use', full_name='CSOEconItem.in_use', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='style', full_name='CSOEconItem.style', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='original_id', full_name='CSOEconItem.original_id', index=15,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='equipped_state', full_name='CSOEconItem.equipped_state', index=16,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rarity', full_name='CSOEconItem.rarity', index=17,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2889,
  serialized_end=3304,
)


_CMSGADJUSTITEMEQUIPPEDSTATE = _descriptor.Descriptor(
  name='CMsgAdjustItemEquippedState',
  full_name='CMsgAdjustItemEquippedState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgAdjustItemEquippedState.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_class', full_name='CMsgAdjustItemEquippedState.new_class', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_slot', full_name='CMsgAdjustItemEquippedState.new_slot', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='swap', full_name='CMsgAdjustItemEquippedState.swap', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3306,
  serialized_end=3403,
)


_CMSGSORTITEMS = _descriptor.Descriptor(
  name='CMsgSortItems',
  full_name='CMsgSortItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sort_type', full_name='CMsgSortItems.sort_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3405,
  serialized_end=3439,
)


_CSOECONCLAIMCODE = _descriptor.Descriptor(
  name='CSOEconClaimCode',
  full_name='CSOEconClaimCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSOEconClaimCode.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='CSOEconClaimCode.code_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_acquired', full_name='CSOEconClaimCode.time_acquired', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code', full_name='CSOEconClaimCode.code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3441,
  serialized_end=3535,
)


_CMSGSTOREGETUSERDATA = _descriptor.Descriptor(
  name='CMsgStoreGetUserData',
  full_name='CMsgStoreGetUserData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='price_sheet_version', full_name='CMsgStoreGetUserData.price_sheet_version', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='CMsgStoreGetUserData.currency', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3537,
  serialized_end=3606,
)


_CMSGSTOREGETUSERDATARESPONSE = _descriptor.Descriptor(
  name='CMsgStoreGetUserDataResponse',
  full_name='CMsgStoreGetUserDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgStoreGetUserDataResponse.result', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency_deprecated', full_name='CMsgStoreGetUserDataResponse.currency_deprecated', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_deprecated', full_name='CMsgStoreGetUserDataResponse.country_deprecated', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price_sheet_version', full_name='CMsgStoreGetUserDataResponse.price_sheet_version', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price_sheet', full_name='CMsgStoreGetUserDataResponse.price_sheet', index=4,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3609,
  serialized_end=3762,
)


_CMSGUPDATEITEMSCHEMA = _descriptor.Descriptor(
  name='CMsgUpdateItemSchema',
  full_name='CMsgUpdateItemSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='items_game', full_name='CMsgUpdateItemSchema.items_game', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_schema_version', full_name='CMsgUpdateItemSchema.item_schema_version', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='items_game_url_DEPRECATED2013', full_name='CMsgUpdateItemSchema.items_game_url_DEPRECATED2013', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='items_game_url', full_name='CMsgUpdateItemSchema.items_game_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3765,
  serialized_end=3899,
)


_CMSGGCERROR = _descriptor.Descriptor(
  name='CMsgGCError',
  full_name='CMsgGCError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_text', full_name='CMsgGCError.error_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3901,
  serialized_end=3934,
)


_CMSGREQUESTINVENTORYREFRESH = _descriptor.Descriptor(
  name='CMsgRequestInventoryRefresh',
  full_name='CMsgRequestInventoryRefresh',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3936,
  serialized_end=3965,
)


_CMSGCONVARVALUE = _descriptor.Descriptor(
  name='CMsgConVarValue',
  full_name='CMsgConVarValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgConVarValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgConVarValue.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3967,
  serialized_end=4013,
)


_CMSGREPLICATECONVARS = _descriptor.Descriptor(
  name='CMsgReplicateConVars',
  full_name='CMsgReplicateConVars',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='convars', full_name='CMsgReplicateConVars.convars', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4015,
  serialized_end=4072,
)


_CMSGUSEITEM = _descriptor.Descriptor(
  name='CMsgUseItem',
  full_name='CMsgUseItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgUseItem.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_steam_id', full_name='CMsgUseItem.target_steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gift__potential_targets', full_name='CMsgUseItem.gift__potential_targets', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duel__class_lock', full_name='CMsgUseItem.duel__class_lock', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initiator_steam_id', full_name='CMsgUseItem.initiator_steam_id', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4075,
  serialized_end=4217,
)


_CMSGREPLAYUPLOADEDTOYOUTUBE = _descriptor.Descriptor(
  name='CMsgReplayUploadedToYouTube',
  full_name='CMsgReplayUploadedToYouTube',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='youtube_url', full_name='CMsgReplayUploadedToYouTube.youtube_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='youtube_account_name', full_name='CMsgReplayUploadedToYouTube.youtube_account_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='CMsgReplayUploadedToYouTube.session_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4219,
  serialized_end=4319,
)


_CMSGCONSUMABLEEXHAUSTED = _descriptor.Descriptor(
  name='CMsgConsumableExhausted',
  full_name='CMsgConsumableExhausted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def_id', full_name='CMsgConsumableExhausted.item_def_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4321,
  serialized_end=4367,
)


_CMSGITEMACKNOWLEDGED__DEPRECATED = _descriptor.Descriptor(
  name='CMsgItemAcknowledged__DEPRECATED',
  full_name='CMsgItemAcknowledged__DEPRECATED',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgItemAcknowledged__DEPRECATED.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inventory', full_name='CMsgItemAcknowledged__DEPRECATED.inventory', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CMsgItemAcknowledged__DEPRECATED.def_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality', full_name='CMsgItemAcknowledged__DEPRECATED.quality', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rarity', full_name='CMsgItemAcknowledged__DEPRECATED.rarity', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin', full_name='CMsgItemAcknowledged__DEPRECATED.origin', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgItemAcknowledged__DEPRECATED.item_id', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4370,
  serialized_end=4528,
)


_CMSGSETITEMPOSITIONS_ITEMPOSITION = _descriptor.Descriptor(
  name='ItemPosition',
  full_name='CMsgSetItemPositions.ItemPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='legacy_item_id', full_name='CMsgSetItemPositions.ItemPosition.legacy_item_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='CMsgSetItemPositions.ItemPosition.position', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgSetItemPositions.ItemPosition.item_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4615,
  serialized_end=4688,
)

_CMSGSETITEMPOSITIONS = _descriptor.Descriptor(
  name='CMsgSetItemPositions',
  full_name='CMsgSetItemPositions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_positions', full_name='CMsgSetItemPositions.item_positions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSETITEMPOSITIONS_ITEMPOSITION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4531,
  serialized_end=4688,
)


_CMSGGCREPORTABUSE = _descriptor.Descriptor(
  name='CMsgGCReportAbuse',
  full_name='CMsgGCReportAbuse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_steam_id', full_name='CMsgGCReportAbuse.target_steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='CMsgGCReportAbuse.description', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gid', full_name='CMsgGCReportAbuse.gid', index=2,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='abuse_type', full_name='CMsgGCReportAbuse.abuse_type', index=3,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='CMsgGCReportAbuse.content_type', index=4,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_game_server_ip', full_name='CMsgGCReportAbuse.target_game_server_ip', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_game_server_port', full_name='CMsgGCReportAbuse.target_game_server_port', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4691,
  serialized_end=4875,
)


_CMSGGCREPORTABUSERESPONSE = _descriptor.Descriptor(
  name='CMsgGCReportAbuseResponse',
  full_name='CMsgGCReportAbuseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_steam_id', full_name='CMsgGCReportAbuseResponse.target_steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCReportAbuseResponse.result', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='CMsgGCReportAbuseResponse.error_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4877,
  serialized_end=4968,
)


_CMSGGCNAMEITEMNOTIFICATION = _descriptor.Descriptor(
  name='CMsgGCNameItemNotification',
  full_name='CMsgGCNameItemNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_steamid', full_name='CMsgGCNameItemNotification.player_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_def_index', full_name='CMsgGCNameItemNotification.item_def_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_name_custom', full_name='CMsgGCNameItemNotification.item_name_custom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4970,
  serialized_end=5072,
)


_CMSGGCCLIENTDISPLAYNOTIFICATION = _descriptor.Descriptor(
  name='CMsgGCClientDisplayNotification',
  full_name='CMsgGCClientDisplayNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='notification_title_localization_key', full_name='CMsgGCClientDisplayNotification.notification_title_localization_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='notification_body_localization_key', full_name='CMsgGCClientDisplayNotification.notification_body_localization_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='body_substring_keys', full_name='CMsgGCClientDisplayNotification.body_substring_keys', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='body_substring_values', full_name='CMsgGCClientDisplayNotification.body_substring_values', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5075,
  serialized_end=5257,
)


_CMSGGCSHOWITEMSPICKEDUP = _descriptor.Descriptor(
  name='CMsgGCShowItemsPickedUp',
  full_name='CMsgGCShowItemsPickedUp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_steamid', full_name='CMsgGCShowItemsPickedUp.player_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5259,
  serialized_end=5308,
)


_CMSGGCINCREMENTKILLCOUNTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCIncrementKillCountResponse',
  full_name='CMsgGCIncrementKillCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='killer_account_id', full_name='CMsgGCIncrementKillCountResponse.killer_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))),
    _descriptor.FieldDescriptor(
      name='num_kills', full_name='CMsgGCIncrementKillCountResponse.num_kills', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_def', full_name='CMsgGCIncrementKillCountResponse.item_def', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level_type', full_name='CMsgGCIncrementKillCountResponse.level_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5310,
  serialized_end=5434,
)


_CSOECONITEMDROPRATEBONUS = _descriptor.Descriptor(
  name='CSOEconItemDropRateBonus',
  full_name='CSOEconItemDropRateBonus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSOEconItemDropRateBonus.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expiration_date', full_name='CSOEconItemDropRateBonus.expiration_date', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bonus', full_name='CSOEconItemDropRateBonus.bonus', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bonus_count', full_name='CSOEconItemDropRateBonus.bonus_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CSOEconItemDropRateBonus.item_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CSOEconItemDropRateBonus.def_index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5437,
  serialized_end=5580,
)


_CSOECONITEMLEAGUEVIEWPASS = _descriptor.Descriptor(
  name='CSOEconItemLeagueViewPass',
  full_name='CSOEconItemLeagueViewPass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSOEconItemLeagueViewPass.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CSOEconItemLeagueViewPass.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))),
    _descriptor.FieldDescriptor(
      name='admin', full_name='CSOEconItemLeagueViewPass.admin', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemindex', full_name='CSOEconItemLeagueViewPass.itemindex', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5582,
  serialized_end=5694,
)


_CSOECONITEMEVENTTICKET = _descriptor.Descriptor(
  name='CSOEconItemEventTicket',
  full_name='CSOEconItemEventTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSOEconItemEventTicket.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CSOEconItemEventTicket.event_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CSOEconItemEventTicket.item_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5696,
  serialized_end=5775,
)


_CMSGGCITEMPREVIEWITEMBOUGHTNOTIFICATION = _descriptor.Descriptor(
  name='CMsgGCItemPreviewItemBoughtNotification',
  full_name='CMsgGCItemPreviewItemBoughtNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def_index', full_name='CMsgGCItemPreviewItemBoughtNotification.item_def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5777,
  serialized_end=5842,
)


_CMSGGCSTOREPURCHASECANCEL = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseCancel',
  full_name='CMsgGCStorePurchaseCancel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txn_id', full_name='CMsgGCStorePurchaseCancel.txn_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5844,
  serialized_end=5887,
)


_CMSGGCSTOREPURCHASECANCELRESPONSE = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseCancelResponse',
  full_name='CMsgGCStorePurchaseCancelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCStorePurchaseCancelResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5889,
  serialized_end=5940,
)


_CMSGGCSTOREPURCHASEFINALIZE = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseFinalize',
  full_name='CMsgGCStorePurchaseFinalize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txn_id', full_name='CMsgGCStorePurchaseFinalize.txn_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5942,
  serialized_end=5987,
)


_CMSGGCSTOREPURCHASEFINALIZERESPONSE = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseFinalizeResponse',
  full_name='CMsgGCStorePurchaseFinalizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCStorePurchaseFinalizeResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_ids', full_name='CMsgGCStorePurchaseFinalizeResponse.item_ids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5989,
  serialized_end=6060,
)


_CMSGGCBANNEDWORDLISTREQUEST = _descriptor.Descriptor(
  name='CMsgGCBannedWordListRequest',
  full_name='CMsgGCBannedWordListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ban_list_group_id', full_name='CMsgGCBannedWordListRequest.ban_list_group_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='word_id', full_name='CMsgGCBannedWordListRequest.word_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6062,
  serialized_end=6135,
)


_CMSGGCREQUESTANNOUNCEMENTS = _descriptor.Descriptor(
  name='CMsgGCRequestAnnouncements',
  full_name='CMsgGCRequestAnnouncements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6137,
  serialized_end=6165,
)


_CMSGGCREQUESTANNOUNCEMENTSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCRequestAnnouncementsResponse',
  full_name='CMsgGCRequestAnnouncementsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='announcement_title', full_name='CMsgGCRequestAnnouncementsResponse.announcement_title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='announcement', full_name='CMsgGCRequestAnnouncementsResponse.announcement', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nextmatch_title', full_name='CMsgGCRequestAnnouncementsResponse.nextmatch_title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nextmatch', full_name='CMsgGCRequestAnnouncementsResponse.nextmatch', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6168,
  serialized_end=6298,
)


_CMSGGCBANNEDWORD = _descriptor.Descriptor(
  name='CMsgGCBannedWord',
  full_name='CMsgGCBannedWord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='word_id', full_name='CMsgGCBannedWord.word_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='word_type', full_name='CMsgGCBannedWord.word_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='word', full_name='CMsgGCBannedWord.word', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6300,
  serialized_end=6417,
)


_CMSGGCBANNEDWORDLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCBannedWordListResponse',
  full_name='CMsgGCBannedWordListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ban_list_group_id', full_name='CMsgGCBannedWordListResponse.ban_list_group_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='word_list', full_name='CMsgGCBannedWordListResponse.word_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6419,
  serialized_end=6514,
)


_CMSGGCTOGCBANNEDWORDLISTBROADCAST = _descriptor.Descriptor(
  name='CMsgGCToGCBannedWordListBroadcast',
  full_name='CMsgGCToGCBannedWordListBroadcast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast', full_name='CMsgGCToGCBannedWordListBroadcast.broadcast', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6516,
  serialized_end=6601,
)


_CMSGGCTOGCBANNEDWORDLISTUPDATED = _descriptor.Descriptor(
  name='CMsgGCToGCBannedWordListUpdated',
  full_name='CMsgGCToGCBannedWordListUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='CMsgGCToGCBannedWordListUpdated.group_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6603,
  serialized_end=6654,
)


_CSOECONDEFAULTEQUIPPEDDEFINITIONINSTANCECLIENT = _descriptor.Descriptor(
  name='CSOEconDefaultEquippedDefinitionInstanceClient',
  full_name='CSOEconDefaultEquippedDefinitionInstanceClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSOEconDefaultEquippedDefinitionInstanceClient.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))),
    _descriptor.FieldDescriptor(
      name='item_definition', full_name='CSOEconDefaultEquippedDefinitionInstanceClient.item_definition', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='class_id', full_name='CSOEconDefaultEquippedDefinitionInstanceClient.class_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))),
    _descriptor.FieldDescriptor(
      name='slot_id', full_name='CSOEconDefaultEquippedDefinitionInstanceClient.slot_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6657,
  serialized_end=6803,
)


_CMSGGCTOGCDIRTYSDOCACHE = _descriptor.Descriptor(
  name='CMsgGCToGCDirtySDOCache',
  full_name='CMsgGCToGCDirtySDOCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sdo_type', full_name='CMsgGCToGCDirtySDOCache.sdo_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key_uint64', full_name='CMsgGCToGCDirtySDOCache.key_uint64', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6805,
  serialized_end=6868,
)


_CMSGGCTOGCDIRTYMULTIPLESDOCACHE = _descriptor.Descriptor(
  name='CMsgGCToGCDirtyMultipleSDOCache',
  full_name='CMsgGCToGCDirtyMultipleSDOCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sdo_type', full_name='CMsgGCToGCDirtyMultipleSDOCache.sdo_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key_uint64', full_name='CMsgGCToGCDirtyMultipleSDOCache.key_uint64', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6870,
  serialized_end=6941,
)


_CMSGGCCOLLECTITEM = _descriptor.Descriptor(
  name='CMsgGCCollectItem',
  full_name='CMsgGCCollectItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_item_id', full_name='CMsgGCCollectItem.collection_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject_item_id', full_name='CMsgGCCollectItem.subject_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6943,
  serialized_end=7015,
)


_CMSGSDONOMEMCACHED = _descriptor.Descriptor(
  name='CMsgSDONoMemcached',
  full_name='CMsgSDONoMemcached',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7017,
  serialized_end=7037,
)


_CMSGGCTOGCUPDATESQLKEYVALUE = _descriptor.Descriptor(
  name='CMsgGCToGCUpdateSQLKeyValue',
  full_name='CMsgGCToGCUpdateSQLKeyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_name', full_name='CMsgGCToGCUpdateSQLKeyValue.key_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7039,
  serialized_end=7086,
)


_CMSGGCTOGCISTRUSTEDSERVER = _descriptor.Descriptor(
  name='CMsgGCToGCIsTrustedServer',
  full_name='CMsgGCToGCIsTrustedServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGCToGCIsTrustedServer.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7088,
  serialized_end=7133,
)


_CMSGGCTOGCISTRUSTEDSERVERRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToGCIsTrustedServerResponse',
  full_name='CMsgGCToGCIsTrustedServerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_trusted', full_name='CMsgGCToGCIsTrustedServerResponse.is_trusted', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7135,
  serialized_end=7190,
)


_CMSGGCTOGCBROADCASTCONSOLECOMMAND = _descriptor.Descriptor(
  name='CMsgGCToGCBroadcastConsoleCommand',
  full_name='CMsgGCToGCBroadcastConsoleCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='con_command', full_name='CMsgGCToGCBroadcastConsoleCommand.con_command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7192,
  serialized_end=7248,
)


_CMSGGCSERVERVERSIONUPDATED = _descriptor.Descriptor(
  name='CMsgGCServerVersionUpdated',
  full_name='CMsgGCServerVersionUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_version', full_name='CMsgGCServerVersionUpdated.server_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7250,
  serialized_end=7302,
)


_CMSGGCCLIENTVERSIONUPDATED = _descriptor.Descriptor(
  name='CMsgGCClientVersionUpdated',
  full_name='CMsgGCClientVersionUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgGCClientVersionUpdated.client_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7304,
  serialized_end=7356,
)


_CMSGGCTOGCWEBAPIACCOUNTCHANGED = _descriptor.Descriptor(
  name='CMsgGCToGCWebAPIAccountChanged',
  full_name='CMsgGCToGCWebAPIAccountChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7358,
  serialized_end=7390,
)


_CMSGGCTOGCREQUESTPASSPORTITEMGRANT = _descriptor.Descriptor(
  name='CMsgGCToGCRequestPassportItemGrant',
  full_name='CMsgGCToGCRequestPassportItemGrant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGCToGCRequestPassportItemGrant.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgGCToGCRequestPassportItemGrant.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reward_flag', full_name='CMsgGCToGCRequestPassportItemGrant.reward_flag', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7392,
  serialized_end=7486,
)


_CMSGGAMESERVERINFO = _descriptor.Descriptor(
  name='CMsgGameServerInfo',
  full_name='CMsgGameServerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_public_ip_addr', full_name='CMsgGameServerInfo.server_public_ip_addr', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_private_ip_addr', full_name='CMsgGameServerInfo.server_private_ip_addr', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_port', full_name='CMsgGameServerInfo.server_port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_tv_port', full_name='CMsgGameServerInfo.server_tv_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_key', full_name='CMsgGameServerInfo.server_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_hibernation', full_name='CMsgGameServerInfo.server_hibernation', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_type', full_name='CMsgGameServerInfo.server_type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_region', full_name='CMsgGameServerInfo.server_region', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_loadavg', full_name='CMsgGameServerInfo.server_loadavg', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_tv_broadcast_time', full_name='CMsgGameServerInfo.server_tv_broadcast_time', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_game_time', full_name='CMsgGameServerInfo.server_game_time', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_relay_connected_steam_id', full_name='CMsgGameServerInfo.server_relay_connected_steam_id', index=11,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='relay_slots_max', full_name='CMsgGameServerInfo.relay_slots_max', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='relays_connected', full_name='CMsgGameServerInfo.relays_connected', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='relay_clients_connected', full_name='CMsgGameServerInfo.relay_clients_connected', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='relayed_game_server_steam_id', full_name='CMsgGameServerInfo.relayed_game_server_steam_id', index=15,
      number=16, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_relay_count', full_name='CMsgGameServerInfo.parent_relay_count', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_secret_code', full_name='CMsgGameServerInfo.tv_secret_code', index=17,
      number=18, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGAMESERVERINFO_SERVERTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7489,
  serialized_end=8105,
)

_CMSGGCSTOREPURCHASEINIT.fields_by_name['line_items'].message_type = _CGCSTOREPURCHASEINIT_LINEITEM
_CSOITEMCRITERIA.fields_by_name['conditions'].message_type = _CSOITEMCRITERIACONDITION
_CSOITEMRECIPE.fields_by_name['input_items_criteria'].message_type = _CSOITEMCRITERIA
_CSOITEMRECIPE.fields_by_name['output_items_criteria'].message_type = _CSOITEMCRITERIA
_CMSGDEVNEWITEMREQUEST.fields_by_name['criteria'].message_type = _CSOITEMCRITERIA
_CSOECONITEM.fields_by_name['attribute'].message_type = _CSOECONITEMATTRIBUTE
_CSOECONITEM.fields_by_name['interior_item'].message_type = _CSOECONITEM
_CSOECONITEM.fields_by_name['equipped_state'].message_type = _CSOECONITEMEQUIPPED
_CMSGREPLICATECONVARS.fields_by_name['convars'].message_type = _CMSGCONVARVALUE
_CMSGSETITEMPOSITIONS_ITEMPOSITION.containing_type = _CMSGSETITEMPOSITIONS
_CMSGSETITEMPOSITIONS.fields_by_name['item_positions'].message_type = _CMSGSETITEMPOSITIONS_ITEMPOSITION
_CMSGGCBANNEDWORD.fields_by_name['word_type'].enum_type = _GC_BANNEDWORDTYPE
_CMSGGCBANNEDWORDLISTRESPONSE.fields_by_name['word_list'].message_type = _CMSGGCBANNEDWORD
_CMSGGCTOGCBANNEDWORDLISTBROADCAST.fields_by_name['broadcast'].message_type = _CMSGGCBANNEDWORDLISTRESPONSE
_CMSGGAMESERVERINFO.fields_by_name['server_type'].enum_type = _CMSGGAMESERVERINFO_SERVERTYPE
_CMSGGAMESERVERINFO_SERVERTYPE.containing_type = _CMSGGAMESERVERINFO
DESCRIPTOR.message_types_by_name['CGCStorePurchaseInit_LineItem'] = _CGCSTOREPURCHASEINIT_LINEITEM
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseInit'] = _CMSGGCSTOREPURCHASEINIT
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseInitResponse'] = _CMSGGCSTOREPURCHASEINITRESPONSE
DESCRIPTOR.message_types_by_name['CSOPartyInvite'] = _CSOPARTYINVITE
DESCRIPTOR.message_types_by_name['CSOLobbyInvite'] = _CSOLOBBYINVITE
DESCRIPTOR.message_types_by_name['CMsgSystemBroadcast'] = _CMSGSYSTEMBROADCAST
DESCRIPTOR.message_types_by_name['CMsgInviteToParty'] = _CMSGINVITETOPARTY
DESCRIPTOR.message_types_by_name['CMsgInvitationCreated'] = _CMSGINVITATIONCREATED
DESCRIPTOR.message_types_by_name['CMsgPartyInviteResponse'] = _CMSGPARTYINVITERESPONSE
DESCRIPTOR.message_types_by_name['CMsgKickFromParty'] = _CMSGKICKFROMPARTY
DESCRIPTOR.message_types_by_name['CMsgLeaveParty'] = _CMSGLEAVEPARTY
DESCRIPTOR.message_types_by_name['CMsgServerAvailable'] = _CMSGSERVERAVAILABLE
DESCRIPTOR.message_types_by_name['CMsgLANServerAvailable'] = _CMSGLANSERVERAVAILABLE
DESCRIPTOR.message_types_by_name['CSOEconGameAccountClient'] = _CSOECONGAMEACCOUNTCLIENT
DESCRIPTOR.message_types_by_name['CSOItemCriteriaCondition'] = _CSOITEMCRITERIACONDITION
DESCRIPTOR.message_types_by_name['CSOItemCriteria'] = _CSOITEMCRITERIA
DESCRIPTOR.message_types_by_name['CSOItemRecipe'] = _CSOITEMRECIPE
DESCRIPTOR.message_types_by_name['CMsgDevNewItemRequest'] = _CMSGDEVNEWITEMREQUEST
DESCRIPTOR.message_types_by_name['CMsgIncrementKillCountAttribute'] = _CMSGINCREMENTKILLCOUNTATTRIBUTE
DESCRIPTOR.message_types_by_name['CMsgApplySticker'] = _CMSGAPPLYSTICKER
DESCRIPTOR.message_types_by_name['CMsgApplyStatTrakSwap'] = _CMSGAPPLYSTATTRAKSWAP
DESCRIPTOR.message_types_by_name['CMsgApplyStrangePart'] = _CMSGAPPLYSTRANGEPART
DESCRIPTOR.message_types_by_name['CMsgApplyPennantUpgrade'] = _CMSGAPPLYPENNANTUPGRADE
DESCRIPTOR.message_types_by_name['CMsgApplyEggEssence'] = _CMSGAPPLYEGGESSENCE
DESCRIPTOR.message_types_by_name['CSOEconItemAttribute'] = _CSOECONITEMATTRIBUTE
DESCRIPTOR.message_types_by_name['CSOEconItemEquipped'] = _CSOECONITEMEQUIPPED
DESCRIPTOR.message_types_by_name['CSOEconItem'] = _CSOECONITEM
DESCRIPTOR.message_types_by_name['CMsgAdjustItemEquippedState'] = _CMSGADJUSTITEMEQUIPPEDSTATE
DESCRIPTOR.message_types_by_name['CMsgSortItems'] = _CMSGSORTITEMS
DESCRIPTOR.message_types_by_name['CSOEconClaimCode'] = _CSOECONCLAIMCODE
DESCRIPTOR.message_types_by_name['CMsgStoreGetUserData'] = _CMSGSTOREGETUSERDATA
DESCRIPTOR.message_types_by_name['CMsgStoreGetUserDataResponse'] = _CMSGSTOREGETUSERDATARESPONSE
DESCRIPTOR.message_types_by_name['CMsgUpdateItemSchema'] = _CMSGUPDATEITEMSCHEMA
DESCRIPTOR.message_types_by_name['CMsgGCError'] = _CMSGGCERROR
DESCRIPTOR.message_types_by_name['CMsgRequestInventoryRefresh'] = _CMSGREQUESTINVENTORYREFRESH
DESCRIPTOR.message_types_by_name['CMsgConVarValue'] = _CMSGCONVARVALUE
DESCRIPTOR.message_types_by_name['CMsgReplicateConVars'] = _CMSGREPLICATECONVARS
DESCRIPTOR.message_types_by_name['CMsgUseItem'] = _CMSGUSEITEM
DESCRIPTOR.message_types_by_name['CMsgReplayUploadedToYouTube'] = _CMSGREPLAYUPLOADEDTOYOUTUBE
DESCRIPTOR.message_types_by_name['CMsgConsumableExhausted'] = _CMSGCONSUMABLEEXHAUSTED
DESCRIPTOR.message_types_by_name['CMsgItemAcknowledged__DEPRECATED'] = _CMSGITEMACKNOWLEDGED__DEPRECATED
DESCRIPTOR.message_types_by_name['CMsgSetItemPositions'] = _CMSGSETITEMPOSITIONS
DESCRIPTOR.message_types_by_name['CMsgGCReportAbuse'] = _CMSGGCREPORTABUSE
DESCRIPTOR.message_types_by_name['CMsgGCReportAbuseResponse'] = _CMSGGCREPORTABUSERESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCNameItemNotification'] = _CMSGGCNAMEITEMNOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgGCClientDisplayNotification'] = _CMSGGCCLIENTDISPLAYNOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgGCShowItemsPickedUp'] = _CMSGGCSHOWITEMSPICKEDUP
DESCRIPTOR.message_types_by_name['CMsgGCIncrementKillCountResponse'] = _CMSGGCINCREMENTKILLCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['CSOEconItemDropRateBonus'] = _CSOECONITEMDROPRATEBONUS
DESCRIPTOR.message_types_by_name['CSOEconItemLeagueViewPass'] = _CSOECONITEMLEAGUEVIEWPASS
DESCRIPTOR.message_types_by_name['CSOEconItemEventTicket'] = _CSOECONITEMEVENTTICKET
DESCRIPTOR.message_types_by_name['CMsgGCItemPreviewItemBoughtNotification'] = _CMSGGCITEMPREVIEWITEMBOUGHTNOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseCancel'] = _CMSGGCSTOREPURCHASECANCEL
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseCancelResponse'] = _CMSGGCSTOREPURCHASECANCELRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseFinalize'] = _CMSGGCSTOREPURCHASEFINALIZE
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseFinalizeResponse'] = _CMSGGCSTOREPURCHASEFINALIZERESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCBannedWordListRequest'] = _CMSGGCBANNEDWORDLISTREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCRequestAnnouncements'] = _CMSGGCREQUESTANNOUNCEMENTS
DESCRIPTOR.message_types_by_name['CMsgGCRequestAnnouncementsResponse'] = _CMSGGCREQUESTANNOUNCEMENTSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCBannedWord'] = _CMSGGCBANNEDWORD
DESCRIPTOR.message_types_by_name['CMsgGCBannedWordListResponse'] = _CMSGGCBANNEDWORDLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCBannedWordListBroadcast'] = _CMSGGCTOGCBANNEDWORDLISTBROADCAST
DESCRIPTOR.message_types_by_name['CMsgGCToGCBannedWordListUpdated'] = _CMSGGCTOGCBANNEDWORDLISTUPDATED
DESCRIPTOR.message_types_by_name['CSOEconDefaultEquippedDefinitionInstanceClient'] = _CSOECONDEFAULTEQUIPPEDDEFINITIONINSTANCECLIENT
DESCRIPTOR.message_types_by_name['CMsgGCToGCDirtySDOCache'] = _CMSGGCTOGCDIRTYSDOCACHE
DESCRIPTOR.message_types_by_name['CMsgGCToGCDirtyMultipleSDOCache'] = _CMSGGCTOGCDIRTYMULTIPLESDOCACHE
DESCRIPTOR.message_types_by_name['CMsgGCCollectItem'] = _CMSGGCCOLLECTITEM
DESCRIPTOR.message_types_by_name['CMsgSDONoMemcached'] = _CMSGSDONOMEMCACHED
DESCRIPTOR.message_types_by_name['CMsgGCToGCUpdateSQLKeyValue'] = _CMSGGCTOGCUPDATESQLKEYVALUE
DESCRIPTOR.message_types_by_name['CMsgGCToGCIsTrustedServer'] = _CMSGGCTOGCISTRUSTEDSERVER
DESCRIPTOR.message_types_by_name['CMsgGCToGCIsTrustedServerResponse'] = _CMSGGCTOGCISTRUSTEDSERVERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCBroadcastConsoleCommand'] = _CMSGGCTOGCBROADCASTCONSOLECOMMAND
DESCRIPTOR.message_types_by_name['CMsgGCServerVersionUpdated'] = _CMSGGCSERVERVERSIONUPDATED
DESCRIPTOR.message_types_by_name['CMsgGCClientVersionUpdated'] = _CMSGGCCLIENTVERSIONUPDATED
DESCRIPTOR.message_types_by_name['CMsgGCToGCWebAPIAccountChanged'] = _CMSGGCTOGCWEBAPIACCOUNTCHANGED
DESCRIPTOR.message_types_by_name['CMsgGCToGCRequestPassportItemGrant'] = _CMSGGCTOGCREQUESTPASSPORTITEMGRANT
DESCRIPTOR.message_types_by_name['CMsgGameServerInfo'] = _CMSGGAMESERVERINFO
DESCRIPTOR.enum_types_by_name['EGCBaseMsg'] = _EGCBASEMSG
DESCRIPTOR.enum_types_by_name['EGCBaseProtoObjectTypes'] = _EGCBASEPROTOOBJECTTYPES
DESCRIPTOR.enum_types_by_name['GC_BannedWordType'] = _GC_BANNEDWORDTYPE

CGCStorePurchaseInit_LineItem = _reflection.GeneratedProtocolMessageType('CGCStorePurchaseInit_LineItem', (_message.Message,), dict(
  DESCRIPTOR = _CGCSTOREPURCHASEINIT_LINEITEM,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CGCStorePurchaseInit_LineItem)
  ))
_sym_db.RegisterMessage(CGCStorePurchaseInit_LineItem)

CMsgGCStorePurchaseInit = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseInit', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASEINIT,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCStorePurchaseInit)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseInit)

CMsgGCStorePurchaseInitResponse = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseInitResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASEINITRESPONSE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCStorePurchaseInitResponse)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseInitResponse)

CSOPartyInvite = _reflection.GeneratedProtocolMessageType('CSOPartyInvite', (_message.Message,), dict(
  DESCRIPTOR = _CSOPARTYINVITE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOPartyInvite)
  ))
_sym_db.RegisterMessage(CSOPartyInvite)

CSOLobbyInvite = _reflection.GeneratedProtocolMessageType('CSOLobbyInvite', (_message.Message,), dict(
  DESCRIPTOR = _CSOLOBBYINVITE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOLobbyInvite)
  ))
_sym_db.RegisterMessage(CSOLobbyInvite)

CMsgSystemBroadcast = _reflection.GeneratedProtocolMessageType('CMsgSystemBroadcast', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSYSTEMBROADCAST,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemBroadcast)
  ))
_sym_db.RegisterMessage(CMsgSystemBroadcast)

CMsgInviteToParty = _reflection.GeneratedProtocolMessageType('CMsgInviteToParty', (_message.Message,), dict(
  DESCRIPTOR = _CMSGINVITETOPARTY,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgInviteToParty)
  ))
_sym_db.RegisterMessage(CMsgInviteToParty)

CMsgInvitationCreated = _reflection.GeneratedProtocolMessageType('CMsgInvitationCreated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGINVITATIONCREATED,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgInvitationCreated)
  ))
_sym_db.RegisterMessage(CMsgInvitationCreated)

CMsgPartyInviteResponse = _reflection.GeneratedProtocolMessageType('CMsgPartyInviteResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPARTYINVITERESPONSE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPartyInviteResponse)
  ))
_sym_db.RegisterMessage(CMsgPartyInviteResponse)

CMsgKickFromParty = _reflection.GeneratedProtocolMessageType('CMsgKickFromParty', (_message.Message,), dict(
  DESCRIPTOR = _CMSGKICKFROMPARTY,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgKickFromParty)
  ))
_sym_db.RegisterMessage(CMsgKickFromParty)

CMsgLeaveParty = _reflection.GeneratedProtocolMessageType('CMsgLeaveParty', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLEAVEPARTY,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLeaveParty)
  ))
_sym_db.RegisterMessage(CMsgLeaveParty)

CMsgServerAvailable = _reflection.GeneratedProtocolMessageType('CMsgServerAvailable', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSERVERAVAILABLE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgServerAvailable)
  ))
_sym_db.RegisterMessage(CMsgServerAvailable)

CMsgLANServerAvailable = _reflection.GeneratedProtocolMessageType('CMsgLANServerAvailable', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLANSERVERAVAILABLE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLANServerAvailable)
  ))
_sym_db.RegisterMessage(CMsgLANServerAvailable)

CSOEconGameAccountClient = _reflection.GeneratedProtocolMessageType('CSOEconGameAccountClient', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONGAMEACCOUNTCLIENT,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconGameAccountClient)
  ))
_sym_db.RegisterMessage(CSOEconGameAccountClient)

CSOItemCriteriaCondition = _reflection.GeneratedProtocolMessageType('CSOItemCriteriaCondition', (_message.Message,), dict(
  DESCRIPTOR = _CSOITEMCRITERIACONDITION,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOItemCriteriaCondition)
  ))
_sym_db.RegisterMessage(CSOItemCriteriaCondition)

CSOItemCriteria = _reflection.GeneratedProtocolMessageType('CSOItemCriteria', (_message.Message,), dict(
  DESCRIPTOR = _CSOITEMCRITERIA,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOItemCriteria)
  ))
_sym_db.RegisterMessage(CSOItemCriteria)

CSOItemRecipe = _reflection.GeneratedProtocolMessageType('CSOItemRecipe', (_message.Message,), dict(
  DESCRIPTOR = _CSOITEMRECIPE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOItemRecipe)
  ))
_sym_db.RegisterMessage(CSOItemRecipe)

CMsgDevNewItemRequest = _reflection.GeneratedProtocolMessageType('CMsgDevNewItemRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDEVNEWITEMREQUEST,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDevNewItemRequest)
  ))
_sym_db.RegisterMessage(CMsgDevNewItemRequest)

CMsgIncrementKillCountAttribute = _reflection.GeneratedProtocolMessageType('CMsgIncrementKillCountAttribute', (_message.Message,), dict(
  DESCRIPTOR = _CMSGINCREMENTKILLCOUNTATTRIBUTE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgIncrementKillCountAttribute)
  ))
_sym_db.RegisterMessage(CMsgIncrementKillCountAttribute)

CMsgApplySticker = _reflection.GeneratedProtocolMessageType('CMsgApplySticker', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYSTICKER,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgApplySticker)
  ))
_sym_db.RegisterMessage(CMsgApplySticker)

CMsgApplyStatTrakSwap = _reflection.GeneratedProtocolMessageType('CMsgApplyStatTrakSwap', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYSTATTRAKSWAP,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgApplyStatTrakSwap)
  ))
_sym_db.RegisterMessage(CMsgApplyStatTrakSwap)

CMsgApplyStrangePart = _reflection.GeneratedProtocolMessageType('CMsgApplyStrangePart', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYSTRANGEPART,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgApplyStrangePart)
  ))
_sym_db.RegisterMessage(CMsgApplyStrangePart)

CMsgApplyPennantUpgrade = _reflection.GeneratedProtocolMessageType('CMsgApplyPennantUpgrade', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYPENNANTUPGRADE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgApplyPennantUpgrade)
  ))
_sym_db.RegisterMessage(CMsgApplyPennantUpgrade)

CMsgApplyEggEssence = _reflection.GeneratedProtocolMessageType('CMsgApplyEggEssence', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYEGGESSENCE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgApplyEggEssence)
  ))
_sym_db.RegisterMessage(CMsgApplyEggEssence)

CSOEconItemAttribute = _reflection.GeneratedProtocolMessageType('CSOEconItemAttribute', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMATTRIBUTE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconItemAttribute)
  ))
_sym_db.RegisterMessage(CSOEconItemAttribute)

CSOEconItemEquipped = _reflection.GeneratedProtocolMessageType('CSOEconItemEquipped', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMEQUIPPED,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconItemEquipped)
  ))
_sym_db.RegisterMessage(CSOEconItemEquipped)

CSOEconItem = _reflection.GeneratedProtocolMessageType('CSOEconItem', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEM,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconItem)
  ))
_sym_db.RegisterMessage(CSOEconItem)

CMsgAdjustItemEquippedState = _reflection.GeneratedProtocolMessageType('CMsgAdjustItemEquippedState', (_message.Message,), dict(
  DESCRIPTOR = _CMSGADJUSTITEMEQUIPPEDSTATE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAdjustItemEquippedState)
  ))
_sym_db.RegisterMessage(CMsgAdjustItemEquippedState)

CMsgSortItems = _reflection.GeneratedProtocolMessageType('CMsgSortItems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSORTITEMS,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSortItems)
  ))
_sym_db.RegisterMessage(CMsgSortItems)

CSOEconClaimCode = _reflection.GeneratedProtocolMessageType('CSOEconClaimCode', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONCLAIMCODE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconClaimCode)
  ))
_sym_db.RegisterMessage(CSOEconClaimCode)

CMsgStoreGetUserData = _reflection.GeneratedProtocolMessageType('CMsgStoreGetUserData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTOREGETUSERDATA,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgStoreGetUserData)
  ))
_sym_db.RegisterMessage(CMsgStoreGetUserData)

CMsgStoreGetUserDataResponse = _reflection.GeneratedProtocolMessageType('CMsgStoreGetUserDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTOREGETUSERDATARESPONSE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgStoreGetUserDataResponse)
  ))
_sym_db.RegisterMessage(CMsgStoreGetUserDataResponse)

CMsgUpdateItemSchema = _reflection.GeneratedProtocolMessageType('CMsgUpdateItemSchema', (_message.Message,), dict(
  DESCRIPTOR = _CMSGUPDATEITEMSCHEMA,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgUpdateItemSchema)
  ))
_sym_db.RegisterMessage(CMsgUpdateItemSchema)

CMsgGCError = _reflection.GeneratedProtocolMessageType('CMsgGCError', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCERROR,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCError)
  ))
_sym_db.RegisterMessage(CMsgGCError)

CMsgRequestInventoryRefresh = _reflection.GeneratedProtocolMessageType('CMsgRequestInventoryRefresh', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTINVENTORYREFRESH,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestInventoryRefresh)
  ))
_sym_db.RegisterMessage(CMsgRequestInventoryRefresh)

CMsgConVarValue = _reflection.GeneratedProtocolMessageType('CMsgConVarValue', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCONVARVALUE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgConVarValue)
  ))
_sym_db.RegisterMessage(CMsgConVarValue)

CMsgReplicateConVars = _reflection.GeneratedProtocolMessageType('CMsgReplicateConVars', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREPLICATECONVARS,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgReplicateConVars)
  ))
_sym_db.RegisterMessage(CMsgReplicateConVars)

CMsgUseItem = _reflection.GeneratedProtocolMessageType('CMsgUseItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGUSEITEM,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgUseItem)
  ))
_sym_db.RegisterMessage(CMsgUseItem)

CMsgReplayUploadedToYouTube = _reflection.GeneratedProtocolMessageType('CMsgReplayUploadedToYouTube', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREPLAYUPLOADEDTOYOUTUBE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgReplayUploadedToYouTube)
  ))
_sym_db.RegisterMessage(CMsgReplayUploadedToYouTube)

CMsgConsumableExhausted = _reflection.GeneratedProtocolMessageType('CMsgConsumableExhausted', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCONSUMABLEEXHAUSTED,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgConsumableExhausted)
  ))
_sym_db.RegisterMessage(CMsgConsumableExhausted)

CMsgItemAcknowledged__DEPRECATED = _reflection.GeneratedProtocolMessageType('CMsgItemAcknowledged__DEPRECATED', (_message.Message,), dict(
  DESCRIPTOR = _CMSGITEMACKNOWLEDGED__DEPRECATED,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgItemAcknowledged__DEPRECATED)
  ))
_sym_db.RegisterMessage(CMsgItemAcknowledged__DEPRECATED)

CMsgSetItemPositions = _reflection.GeneratedProtocolMessageType('CMsgSetItemPositions', (_message.Message,), dict(

  ItemPosition = _reflection.GeneratedProtocolMessageType('ItemPosition', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSETITEMPOSITIONS_ITEMPOSITION,
    __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSetItemPositions.ItemPosition)
    ))
  ,
  DESCRIPTOR = _CMSGSETITEMPOSITIONS,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSetItemPositions)
  ))
_sym_db.RegisterMessage(CMsgSetItemPositions)
_sym_db.RegisterMessage(CMsgSetItemPositions.ItemPosition)

CMsgGCReportAbuse = _reflection.GeneratedProtocolMessageType('CMsgGCReportAbuse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREPORTABUSE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCReportAbuse)
  ))
_sym_db.RegisterMessage(CMsgGCReportAbuse)

CMsgGCReportAbuseResponse = _reflection.GeneratedProtocolMessageType('CMsgGCReportAbuseResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREPORTABUSERESPONSE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCReportAbuseResponse)
  ))
_sym_db.RegisterMessage(CMsgGCReportAbuseResponse)

CMsgGCNameItemNotification = _reflection.GeneratedProtocolMessageType('CMsgGCNameItemNotification', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCNAMEITEMNOTIFICATION,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCNameItemNotification)
  ))
_sym_db.RegisterMessage(CMsgGCNameItemNotification)

CMsgGCClientDisplayNotification = _reflection.GeneratedProtocolMessageType('CMsgGCClientDisplayNotification', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCLIENTDISPLAYNOTIFICATION,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCClientDisplayNotification)
  ))
_sym_db.RegisterMessage(CMsgGCClientDisplayNotification)

CMsgGCShowItemsPickedUp = _reflection.GeneratedProtocolMessageType('CMsgGCShowItemsPickedUp', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSHOWITEMSPICKEDUP,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCShowItemsPickedUp)
  ))
_sym_db.RegisterMessage(CMsgGCShowItemsPickedUp)

CMsgGCIncrementKillCountResponse = _reflection.GeneratedProtocolMessageType('CMsgGCIncrementKillCountResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCINCREMENTKILLCOUNTRESPONSE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCIncrementKillCountResponse)
  ))
_sym_db.RegisterMessage(CMsgGCIncrementKillCountResponse)

CSOEconItemDropRateBonus = _reflection.GeneratedProtocolMessageType('CSOEconItemDropRateBonus', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMDROPRATEBONUS,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconItemDropRateBonus)
  ))
_sym_db.RegisterMessage(CSOEconItemDropRateBonus)

CSOEconItemLeagueViewPass = _reflection.GeneratedProtocolMessageType('CSOEconItemLeagueViewPass', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMLEAGUEVIEWPASS,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconItemLeagueViewPass)
  ))
_sym_db.RegisterMessage(CSOEconItemLeagueViewPass)

CSOEconItemEventTicket = _reflection.GeneratedProtocolMessageType('CSOEconItemEventTicket', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMEVENTTICKET,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconItemEventTicket)
  ))
_sym_db.RegisterMessage(CSOEconItemEventTicket)

CMsgGCItemPreviewItemBoughtNotification = _reflection.GeneratedProtocolMessageType('CMsgGCItemPreviewItemBoughtNotification', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMPREVIEWITEMBOUGHTNOTIFICATION,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCItemPreviewItemBoughtNotification)
  ))
_sym_db.RegisterMessage(CMsgGCItemPreviewItemBoughtNotification)

CMsgGCStorePurchaseCancel = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseCancel', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASECANCEL,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCStorePurchaseCancel)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseCancel)

CMsgGCStorePurchaseCancelResponse = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseCancelResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASECANCELRESPONSE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCStorePurchaseCancelResponse)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseCancelResponse)

CMsgGCStorePurchaseFinalize = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseFinalize', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASEFINALIZE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCStorePurchaseFinalize)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseFinalize)

CMsgGCStorePurchaseFinalizeResponse = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseFinalizeResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASEFINALIZERESPONSE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCStorePurchaseFinalizeResponse)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseFinalizeResponse)

CMsgGCBannedWordListRequest = _reflection.GeneratedProtocolMessageType('CMsgGCBannedWordListRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCBANNEDWORDLISTREQUEST,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCBannedWordListRequest)
  ))
_sym_db.RegisterMessage(CMsgGCBannedWordListRequest)

CMsgGCRequestAnnouncements = _reflection.GeneratedProtocolMessageType('CMsgGCRequestAnnouncements', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREQUESTANNOUNCEMENTS,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCRequestAnnouncements)
  ))
_sym_db.RegisterMessage(CMsgGCRequestAnnouncements)

CMsgGCRequestAnnouncementsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCRequestAnnouncementsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREQUESTANNOUNCEMENTSRESPONSE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCRequestAnnouncementsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCRequestAnnouncementsResponse)

CMsgGCBannedWord = _reflection.GeneratedProtocolMessageType('CMsgGCBannedWord', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCBANNEDWORD,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCBannedWord)
  ))
_sym_db.RegisterMessage(CMsgGCBannedWord)

CMsgGCBannedWordListResponse = _reflection.GeneratedProtocolMessageType('CMsgGCBannedWordListResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCBANNEDWORDLISTRESPONSE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCBannedWordListResponse)
  ))
_sym_db.RegisterMessage(CMsgGCBannedWordListResponse)

CMsgGCToGCBannedWordListBroadcast = _reflection.GeneratedProtocolMessageType('CMsgGCToGCBannedWordListBroadcast', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCBANNEDWORDLISTBROADCAST,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCBannedWordListBroadcast)
  ))
_sym_db.RegisterMessage(CMsgGCToGCBannedWordListBroadcast)

CMsgGCToGCBannedWordListUpdated = _reflection.GeneratedProtocolMessageType('CMsgGCToGCBannedWordListUpdated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCBANNEDWORDLISTUPDATED,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCBannedWordListUpdated)
  ))
_sym_db.RegisterMessage(CMsgGCToGCBannedWordListUpdated)

CSOEconDefaultEquippedDefinitionInstanceClient = _reflection.GeneratedProtocolMessageType('CSOEconDefaultEquippedDefinitionInstanceClient', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONDEFAULTEQUIPPEDDEFINITIONINSTANCECLIENT,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconDefaultEquippedDefinitionInstanceClient)
  ))
_sym_db.RegisterMessage(CSOEconDefaultEquippedDefinitionInstanceClient)

CMsgGCToGCDirtySDOCache = _reflection.GeneratedProtocolMessageType('CMsgGCToGCDirtySDOCache', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCDIRTYSDOCACHE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCDirtySDOCache)
  ))
_sym_db.RegisterMessage(CMsgGCToGCDirtySDOCache)

CMsgGCToGCDirtyMultipleSDOCache = _reflection.GeneratedProtocolMessageType('CMsgGCToGCDirtyMultipleSDOCache', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCDIRTYMULTIPLESDOCACHE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCDirtyMultipleSDOCache)
  ))
_sym_db.RegisterMessage(CMsgGCToGCDirtyMultipleSDOCache)

CMsgGCCollectItem = _reflection.GeneratedProtocolMessageType('CMsgGCCollectItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCOLLECTITEM,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCollectItem)
  ))
_sym_db.RegisterMessage(CMsgGCCollectItem)

CMsgSDONoMemcached = _reflection.GeneratedProtocolMessageType('CMsgSDONoMemcached', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSDONOMEMCACHED,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSDONoMemcached)
  ))
_sym_db.RegisterMessage(CMsgSDONoMemcached)

CMsgGCToGCUpdateSQLKeyValue = _reflection.GeneratedProtocolMessageType('CMsgGCToGCUpdateSQLKeyValue', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCUPDATESQLKEYVALUE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCUpdateSQLKeyValue)
  ))
_sym_db.RegisterMessage(CMsgGCToGCUpdateSQLKeyValue)

CMsgGCToGCIsTrustedServer = _reflection.GeneratedProtocolMessageType('CMsgGCToGCIsTrustedServer', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCISTRUSTEDSERVER,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCIsTrustedServer)
  ))
_sym_db.RegisterMessage(CMsgGCToGCIsTrustedServer)

CMsgGCToGCIsTrustedServerResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToGCIsTrustedServerResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCISTRUSTEDSERVERRESPONSE,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCIsTrustedServerResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToGCIsTrustedServerResponse)

CMsgGCToGCBroadcastConsoleCommand = _reflection.GeneratedProtocolMessageType('CMsgGCToGCBroadcastConsoleCommand', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCBROADCASTCONSOLECOMMAND,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCBroadcastConsoleCommand)
  ))
_sym_db.RegisterMessage(CMsgGCToGCBroadcastConsoleCommand)

CMsgGCServerVersionUpdated = _reflection.GeneratedProtocolMessageType('CMsgGCServerVersionUpdated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSERVERVERSIONUPDATED,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCServerVersionUpdated)
  ))
_sym_db.RegisterMessage(CMsgGCServerVersionUpdated)

CMsgGCClientVersionUpdated = _reflection.GeneratedProtocolMessageType('CMsgGCClientVersionUpdated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCLIENTVERSIONUPDATED,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCClientVersionUpdated)
  ))
_sym_db.RegisterMessage(CMsgGCClientVersionUpdated)

CMsgGCToGCWebAPIAccountChanged = _reflection.GeneratedProtocolMessageType('CMsgGCToGCWebAPIAccountChanged', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCWEBAPIACCOUNTCHANGED,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCWebAPIAccountChanged)
  ))
_sym_db.RegisterMessage(CMsgGCToGCWebAPIAccountChanged)

CMsgGCToGCRequestPassportItemGrant = _reflection.GeneratedProtocolMessageType('CMsgGCToGCRequestPassportItemGrant', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCREQUESTPASSPORTITEMGRANT,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCRequestPassportItemGrant)
  ))
_sym_db.RegisterMessage(CMsgGCToGCRequestPassportItemGrant)

CMsgGameServerInfo = _reflection.GeneratedProtocolMessageType('CMsgGameServerInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGAMESERVERINFO,
  __module__ = 'demoparser.protobufs.base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGameServerInfo)
  ))
_sym_db.RegisterMessage(CMsgGameServerInfo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\200\001\000'))
_CSOPARTYINVITE.fields_by_name['group_id'].has_options = True
_CSOPARTYINVITE.fields_by_name['group_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))
_CSOLOBBYINVITE.fields_by_name['group_id'].has_options = True
_CSOLOBBYINVITE.fields_by_name['group_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))
_CMSGGCINCREMENTKILLCOUNTRESPONSE.fields_by_name['killer_account_id'].has_options = True
_CMSGGCINCREMENTKILLCOUNTRESPONSE.fields_by_name['killer_account_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))
_CSOECONITEMLEAGUEVIEWPASS.fields_by_name['account_id'].has_options = True
_CSOECONITEMLEAGUEVIEWPASS.fields_by_name['account_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))
_CSOECONITEMLEAGUEVIEWPASS.fields_by_name['league_id'].has_options = True
_CSOECONITEMLEAGUEVIEWPASS.fields_by_name['league_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))
_CSOECONDEFAULTEQUIPPEDDEFINITIONINSTANCECLIENT.fields_by_name['account_id'].has_options = True
_CSOECONDEFAULTEQUIPPEDDEFINITIONINSTANCECLIENT.fields_by_name['account_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))
_CSOECONDEFAULTEQUIPPEDDEFINITIONINSTANCECLIENT.fields_by_name['class_id'].has_options = True
_CSOECONDEFAULTEQUIPPEDDEFINITIONINSTANCECLIENT.fields_by_name['class_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))
_CSOECONDEFAULTEQUIPPEDDEFINITIONINSTANCECLIENT.fields_by_name['slot_id'].has_options = True
_CSOECONDEFAULTEQUIPPEDDEFINITIONINSTANCECLIENT.fields_by_name['slot_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))
# @@protoc_insertion_point(module_scope)
